==> ArrayPil-1.1.tar.gz: ArrayPil-1.1/README.md <==
# ArrayPil
---
The library that translates the Pillow image into a Numpy array and on the contrary. It also allows you to save images from the Numpy array.
The library is designed to facilitate and understand the code.
I also apologize for my crooked English translation.
Author's website:
https://tatem.pythonanywhere.com/
---
# Example of using the library:
## importing ArrayPil
```python
from ArrayPil import ArrayPil
```
## importing numpy and pillow
```python
from PIL import Image
import numpy as np
```
## put the ArrayPil class in a variable
```python
ArrayPil = ArrayPil()
```
## we will get a array numpy the image that we took from our folder (your folder)
```python
# the first parameter is the location of the image 
# the second parameter is the default RGB color model
num_array = ArrayPil.ConvImgArray('image1.jpg')
print(num_array)
```
## convert the a array numpy into a picture
```python
# the first parameter is a array numpy
# the second parameter is the location where the image is saved
# the third parameter is the default RGB color model
ArrayPil.ImgSave(num_array, 'res.jpg')
```
## convert the numpy array to a pillow image
```python
# the first parameter is a array numpy
# the second parameter is the default RGB color model
pil_img = ArrayPil.ConvImgPil(num_array)
print(pil_img)
```
## convert pillow images to numpy array
```python
# the first parameter is the pillow image
# the second parameter is the default RGB color model
num_array2 = ArrayPil.ConvPilArray(pil_img)
print(num_array2)
```

==> ArrayPil-1.1.1.tar.gz: ArrayPil-1.1.1/README.md <==
# ArrayPil
---
The library that translates the Pillow image into a Numpy array and on the contrary. It also allows you to save images from the Numpy array.
The library is designed to facilitate and understand the code.
I also apologize for my crooked English translation.
Author's website:
https://tatem.pythonanywhere.com/
---
# Example of using the library:
## importing ArrayPil
```python
from ArrayPil import ArrayPil
```
## importing numpy and pillow
```python
from PIL import Image
import numpy as np
```
## put the ArrayPil class in a variable
```python
ArrayPilClass = ArrayPil()
```
## we will get a array numpy the image that we took from our folder (your folder)
```python
# the first parameter is the location of the image 
# the second parameter is the default RGB color model
num_array = ArrayPilClass.ConvImgArray('image1.jpg')
print(num_array)
```
## convert the a array numpy into a picture
```python
# the first parameter is a array numpy
# the second parameter is the location where the image is saved
# the third parameter is the default RGB color model
ArrayPilClass.ImgSave(num_array, 'res.jpg')
```
## convert the numpy array to a pillow image
```python
# the first parameter is a array numpy
# the second parameter is the default RGB color model
pil_img = ArrayPilClass.ConvImgPil(num_array)
print(pil_img)
```
## convert pillow images to numpy array
```python
# the first parameter is the pillow image
# the second parameter is the default RGB color model
num_array2 = ArrayPilClass.ConvPilArray(pil_img)
print(num_array2)
```
## you can also get methods without creating an instance of the class
## example of the method ConvImgArray
```python
# Instead of ArrayPilClass writing ArrayPil
num_array = ArrayPil.ConvImgArray('image1.jpg')
print(num_array)
```
